@@ -3,12 +3,14 @@ mod dynamodb;
 mod mysql;
 mod postgres;
 mod redis;
+mod tidb;
 
 pub use cassandra::Cassandra;
 pub use dynamodb::DynamoDB;
-pub use mysql::Mysql;
-pub use postgres::Postgres;
+pub use mysql::MySQL;
+pub use postgres::PostgreSQL;
 pub use redis::Redis;
+pub use tidb::TiDB;
 
 #[macro_export]
 macro_rules! svec {
